intelmq.bots.outputs.udp package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.outputs.udp package

## Submodules

## intelmq.bots.outputs.udp.output module

`intelmq.bots.outputs.udp.output.` `BOT`

  alias of `intelmq.bots.outputs.udp.output.UDPOutputBot`

class `intelmq.bots.outputs.udp.output.` `UDPOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Send events to a UDP server, e.g. a syslog daemon

  `delimited`(event)
  `field_delimiter`: str = '|'
  `format`: str = None
  `header`: str = '<header text>'
  `init`()
  `keep_raw_field`: bool = False
  `process`()
  `remove_control_char`(s)
  `send`(rawdata)
  `udp_host`: str = 'localhost'
  `udp_port`: int = None

## Module contents